Index: wp-admin/includes/misc.php
===================================================================
--- wp-admin/includes/misc.php	(revision 11710)
+++ wp-admin/includes/misc.php	(working copy)
@@ -141,11 +141,11 @@
  * Updates the IIS web.config file with the current rules if it is writable.
  * If the permalinks do not require rewrite rules then the rules are deleted from the web.config file.
  *
- * @since 2.8.0
+ * @since 2.9.0
  *
  * @return bool True if web.config was updated successfully
  */
-function iis7_save_url_rewrite_rules(){
+function iis_save_url_rewrite_rules() {
 	global $wp_rewrite;
 
 	$home_path = get_home_path();
@@ -153,12 +153,12 @@
 
 	// Using win_is_writable() instead of is_writable() because of a bug in Windows PHP
 	if ( ( ! file_exists($web_config_file) && win_is_writable($home_path) && $wp_rewrite->using_mod_rewrite_permalinks() ) || win_is_writable($web_config_file) ) {
-		if ( iis7_supports_permalinks() ) {
-			$rule = $wp_rewrite->iis7_url_rewrite_rules();
+		if ( iis_supports_permalinks() ) {
+			$rule = $wp_rewrite->iis_url_rewrite_rules();
 			if ( ! empty($rule) ) {
-				return iis7_add_rewrite_rule($web_config_file, $rule);
+				return iis_add_rewrite_rule($web_config_file, $rule);
 			} else {
-				return iis7_delete_rewrite_rule($web_config_file);
+				return iis_delete_rewrite_rule($web_config_file);
 			}
 		}
 	}
@@ -429,42 +429,41 @@
 }
 
 /**
- * Check if IIS 7 supports pretty permalinks
+ * Check if IIS supports pretty permalinks via URL Rewrite Module
  *
- * @since 2.8.0
+ * @since 2.9.0
  *
  * @return bool
  */
-function iis7_supports_permalinks() {
-	global $is_iis7;
+function iis_supports_permalinks() {
+	global $is_IIS;
 
-	$supports_permalinks = false;
-	if ( $is_iis7 ) {
-		/* First we check if the DOMDocument class exists. If it does not exist,
-		 * which is the case for PHP 4.X, then we cannot easily update the xml configuration file,
-		 * hence we just bail out and tell user that pretty permalinks cannot be used.
-		 * This is not a big issue because PHP 4.X is going to be depricated and for IIS it
-		 * is recommended to use PHP 5.X NTS.
-		 * Next we check if the URL Rewrite Module 1.1 is loaded and enabled for the web site. When
-		 * URL Rewrite 1.1 is loaded it always sets a server variable called 'IIS_UrlRewriteModule'.
-		 * Lastly we make sure that PHP is running via FastCGI. This is important because if it runs
-		 * via ISAPI then pretty permalinks will not work.
-		 */
-		$supports_permalinks = class_exists('DOMDocument') && isset($_SERVER['IIS_UrlRewriteModule']) && ( php_sapi_name() == 'cgi-fcgi' );
-	}
-
-	return apply_filters('iis7_supports_permalinks', $supports_permalinks);
+	/* First we check if the DOMDocument class exists. If it does not exist,
+	 * which is the case for PHP 4.X, then we cannot easily update the xml configuration file,
+	 * hence we just bail out and tell user that pretty permalinks cannot be used.
+	 * This is not a big issue because PHP 4.X is going to be depricated and for IIS it
+	 * is recommended to use PHP 5.X NTS.
+	 * Next we check if the URL Rewrite Module 1.1 is loaded and enabled for the web site. When
+	 * URL Rewrite 1.1 is loaded it always sets a server variable called 'IIS_UrlRewriteModule'.
+	 * Lastly we make sure that PHP is running via FastCGI. This is important because if it runs
+	 * via ISAPI then pretty permalinks will not work.
+	 */
+	$supports_permalinks = $is_IIS && class_exists('DOMDocument') && isset($_SERVER['IIS_UrlRewriteModule']) && ( php_sapi_name() == 'cgi-fcgi' );
+	
+	$supports_permalinks = apply_filters('iis7_supports_permalinks', $supports_permalinks);
+	
+	return apply_filters('iis_supports_permalinks', $supports_permalinks);
 }
 
 /**
- * Check if rewrite rule for WordPress already exists in the IIS 7 configuration file
+ * Check if rewrite rule for WordPress already exists in the IIS configuration file
  *
- * @since 2.8.0
+ * @since 2.9.0
  *
  * @return bool
  * @param string $filename The file path to the configuration file
  */
-function iis7_rewrite_rule_exists($filename) {
+function iis_rewrite_rule_exists($filename) {
 	if ( ! file_exists($filename) )
 		return false;
 	if ( ! class_exists('DOMDocument') )
@@ -484,12 +483,12 @@
 /**
  * Delete WordPress rewrite rule from web.config file if it exists there
  *
- * @since 2.8.0
+ * @since 2.9.0
  *
  * @param string $filename Name of the configuration file
  * @return bool
  */
-function iis7_delete_rewrite_rule($filename) {
+function iis_delete_rewrite_rule($filename) {
 	// If configuration file does not exist then rules also do not exist so there is nothing to delete
 	if ( ! file_exists($filename) )
 		return true;
@@ -515,15 +514,15 @@
 }
 
 /**
- * Add WordPress rewrite rule to the IIS 7 configuration file.
+ * Add WordPress rewrite rule to the IIS configuration file.
  *
- * @since 2.8.0
+ * @since 2.9.0
  *
  * @param string $filename The file path to the configuration file
  * @param string $rewrite_rule The XML fragment with URL Rewrite rule
  * @return bool
  */
-function iis7_add_rewrite_rule($filename, $rewrite_rule) {
+function iis_add_rewrite_rule($filename, $rewrite_rule) {
 	if ( ! class_exists('DOMDocument') )
 		return false;
 
Index: wp-admin/options-permalink.php
===================================================================
--- wp-admin/options-permalink.php	(revision 11710)
+++ wp-admin/options-permalink.php	(working copy)
@@ -70,7 +70,7 @@
 include('admin-header.php');
 
 $home_path = get_home_path();
-$iis7_permalinks = iis7_supports_permalinks();
+$iis_permalinks = iis_supports_permalinks();
 
 if ( isset($_POST['permalink_structure']) || isset($_POST['category_base']) ) {
 	check_admin_referer('update-permalink');
@@ -101,7 +101,7 @@
 $category_base = get_option('category_base');
 $tag_base = get_option( 'tag_base' );
 
-if ( $iis7_permalinks ) {
+if ( $iis_permalinks ) {
 	if ( ( ! file_exists($home_path . 'web.config') && win_is_writable($home_path) ) || win_is_writable($home_path . 'web.config') )
 		$writable = true;
 	else
@@ -123,7 +123,7 @@
 
 <?php if (isset($_POST['submit'])) : ?>
 <div id="message" class="updated fade"><p><?php
-if ( $iis7_permalinks ) {
+if ( $iis_permalinks ) {
 	if ( $permalink_structure && ! $usingpi && ! $writable )
 		_e('You should update your web.config now');
 	else if ( $permalink_structure && ! $usingpi && $writable)
@@ -152,7 +152,7 @@
 <?php
 $prefix = '';
 
-if ( ! got_mod_rewrite() && ! $iis7_permalinks )
+if ( ! got_mod_rewrite() && ! $iis_permalinks )
 	$prefix = '/index.php';
 
 $structures = array(
@@ -197,7 +197,7 @@
 </table>
 
 <h3><?php _e('Optional'); ?></h3>
-<?php if ( $is_apache || $iis7_permalinks ) : ?>
+<?php if ( $is_apache || $iis_permalinks ) : ?>
 	<p><?php _e('If you like, you may enter custom structures for your category and tag <abbr title="Universal Resource Locator">URL</abbr>s here. For example, using <kbd>topics</kbd> as your category base would make your category links like <code>http://example.org/topics/uncategorized/</code>. If you leave these blank the defaults will be used.') ?></p>
 <?php else : ?>
 	<p><?php _e('If you like, you may enter custom structures for your category and tag <abbr title="Universal Resource Locator">URL</abbr>s here. For example, using <code>topics</code> as your category base would make your category links like <code>http://example.org/index.php/topics/uncategorized/</code>. If you leave these blank the defaults will be used.') ?></p>
@@ -221,12 +221,12 @@
 	<input type="submit" name="submit" class="button-primary" value="<?php esc_attr_e('Save Changes') ?>" />
 </p>
   </form>
-<?php if ($iis7_permalinks) :
+<?php if ($iis_permalinks) :
 	if ( isset($_POST['submit']) && $permalink_structure && ! $usingpi && ! $writable ) : ?>
 <p><?php _e('If your <code>web.config</code> file were <a href="http://codex.wordpress.org/Changing_File_Permissions">writable</a>, we could do this automatically, but it isn&#8217;t so this is the url rewrite rule you should have in your <code>web.config</code> file. Click in the field and press <kbd>CTRL + a</kbd> to select all. Then insert this rule inside of the <code>/&lt;configuration&gt;/&lt;system.webServer&gt;/&lt;rewrite&gt;/&lt;rules&gt;</code> element in <code>web.config</code> file.') ?></p>
 <form action="options-permalink.php" method="post">
 <?php wp_nonce_field('update-permalink') ?>
-	<p><textarea rows="10" class="large-text readonly" name="rules" id="rules" readonly="readonly"><?php echo esc_html($wp_rewrite->iis7_url_rewrite_rules()); ?></textarea></p>
+	<p><textarea rows="10" class="large-text readonly" name="rules" id="rules" readonly="readonly"><?php echo esc_html($wp_rewrite->iis_url_rewrite_rules()); ?></textarea></p>
 </form>
 <p><?php _e('If you temporarily make your <code>web.config</code> file writable for us to generate rewrite rules automatically, do not forget to revert the permissions after rule has been saved.')  ?></p>
 	<?php endif; ?>
Index: wp-includes/deprecated.php
===================================================================
--- wp-includes/deprecated.php	(revision 11710)
+++ wp-includes/deprecated.php	(working copy)
@@ -74,6 +74,13 @@
  */
 $tablepostmeta = $wpdb->postmeta;
 
+/**
+ * Whether the server software is IIS 7.X
+ * @global bool $is_iis7
+ * @deprecated Detect IIS version using local code
+ */
+$is_iis7 = (strpos($_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS/7.') !== false);
+
 /*
  * Deprecated functions come here to die.
  */
@@ -1690,4 +1697,80 @@
 	the_author_meta('ID');
 }
 
+/**
+ * Updates the IIS web.config file with the current rules if it is writable.
+ * If the permalinks do not require rewrite rules then the rules are deleted from the web.config file.
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_save_url_rewrite_rules()
+ */
+function iis7_save_url_rewrite_rules() {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_save_url_rewrite_rules()');
+	return iis_save_url_rewrite_rules();
+}
+
+/**
+ * Check if IIS 7 supports pretty permalinks
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_supports_permalinks()
+ */
+function iis7_supports_permalinks() {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_supports_permalinks()');
+	return iis_supports_permalinks();
+}
+
+/**
+ * Check if rewrite rule for WordPress already exists in the IIS 7 configuration file
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_supports_permalinks($filename)
+ */
+function iis7_rewrite_rule_exists($filename) {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_rewrite_rule_exists($filename)');
+	return iis_rewrite_rule_exists($filename);
+}
+
+/**
+ * Delete WordPress rewrite rule from web.config file if it exists there
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_delete_rewrite_rule($filename)
+ */
+function iis7_delete_rewrite_rule($filename) {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_delete_rewrite_rule($filename)');
+	return iis_delete_rewrite_rule($filename);
+}
+
+/**
+ * Add WordPress rewrite rule to the IIS 7 configuration file.
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_add_rewrite_rule($filename, $rewrite_rule)
+ */
+function iis7_add_rewrite_rule($filename, $rewrite_rule) {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_add_rewrite_rule($filename, $rewrite_rule)');
+	return iis_add_rewrite_rule($filename, $rewrite_rule);
+}
+
+
+/**
+ * Retrieve IIS 7 URL Rewrite formatted rewrite rules to write to web.config file.
+ *
+ * Does not actually write to the web.config file, but creates the rules for
+ * the process that will.
+ *
+ * @since 2.8.0
+ * @deprecated 2.9.0
+ * @uses iis_url_rewrite_rules()
+ */
+function iis7_url_rewrite_rules() {
+	_deprecated_function(__FUNCTION__, '2.9', 'iis_url_rewrite_rules()');
+	return iis_url_rewrite_rules();
+}
 ?>
\ No newline at end of file
Index: wp-includes/vars.php
===================================================================
--- wp-includes/vars.php	(revision 11710)
+++ wp-includes/vars.php	(working copy)
@@ -73,11 +73,4 @@
  */
 $is_IIS = (strpos($_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS') !== false || strpos($_SERVER['SERVER_SOFTWARE'], 'ExpressionDevServer') !== false);
 
-/**
- * Whether the server software is IIS 7.X
- * @global bool $is_iis7
- */
-$is_iis7 = (strpos($_SERVER['SERVER_SOFTWARE'], 'Microsoft-IIS/7.') !== false);
-
-
 ?>
\ No newline at end of file

Index: wp-includes/rewrite.php
===================================================================
--- wp-includes/rewrite.php	(revision 11710)
+++ wp-includes/rewrite.php	(working copy)
@@ -1705,17 +1705,17 @@
 	}
 
 	/**
 	 * Retrieve IIS7 URL Rewrite formatted rewrite rules to write to web.config file.
 	 *
 	 * Does not actually write to the web.config file, but creates the rules for
 	 * the process that will.
 	 *
-	 * @since 2.8.0
+	 * @since 2.9.0
 	 * @access public
 	 *
 	 * @return string
 	 */
-	function iis7_url_rewrite_rules(){
+	function iis_url_rewrite_rules() {
 
 		if ( ! $this->using_permalinks()) {
 			return '';
@@ -1730,6 +1730,7 @@
 		$rules .= "</rule>";
 
 		$rules = apply_filters('iis7_url_rewrite_rules', $rules);
+		$rules = apply_filters('iis_url_rewrite_rules', $rules);
 
 		return $rules;
 	}
@@ -1829,8 +1830,8 @@
 		$this->wp_rewrite_rules();
 		if ( $hard && function_exists('save_mod_rewrite_rules') )
 			save_mod_rewrite_rules();
-		if ( $hard && function_exists('iis7_save_url_rewrite_rules') )
-			iis7_save_url_rewrite_rules();
+		if ( $hard && function_exists('iis_save_url_rewrite_rules') )
+			iis_save_url_rewrite_rules();
 	}
 
 	/**
@@ -1705,17 +1705,17 @@
 
 	/**
-	 * Retrieve IIS7 URL Rewrite formatted rewrite rules to write to web.config file.
+	 * Retrieve IIS URL Rewrite formatted rewrite rules to write to web.config file.
 	 *
 	 * Does not actually write to the web.config file, but creates the rules for